@@ -201,18 +201,18 @@ def mqtt_result_code(rc):
 
 def check_digi_cert_ca():
     try:
-        f = open("DigiCertCA.crt")
-        logging.debug("DigiCertCA.crt exist.")
+        f = open(DIGI_CERT_CA)
+        logging.debug(DIGI_CERT_CA + " exist.")
         f.close()
     except IOError:
-        logging.debug("DigiCertCA.crt missing, downloading...")
+        logging.debug(DIGI_CERT_CA + " missing, downloading...")
         # Send HTTP GET request to github to fetch the certificate
         response = requests.get("https://raw.githubusercontent.com/datacentricdesign/dcd-hub/develop/certs/DigiCertCA.crt")
         # If the HTTP GET request can be served
         if response.status_code == 200:
             # Write the file contents in the response to a file specified by
             # local_file_path
-            with open("DigiCertCA.crt", "wb") as local_file:
+            with open(DIGI_CERT_CA, "wb") as local_file:
                 for chunk in response.iter_content(chunk_size=128):
                     local_file.write(chunk)
             logging.debug("DigiCertCA.crt downloaded.")
